#!/usr/bin/env bash

# Debug: uncomment 2 lines to activate debugging
# PS4='$LINENO: '
# set -x

# # # INSTRUCTIONS # # #
# # Step One: Change the 'specimenPath' (line 35) to the path of the folder that 
# includes the html and css
# # Step Two: Open Terminal
# # Step Three: Type the following into the terminal and hit 'enter' after each line, 
# don't include the $ or #
#
# $ cd <drag the folder of fonts into terminal>
# $ <path to script>/make-specimens.sh autohint
#
# ( replace <path to script> with the path to 'make-specimens.sh', 
# that looks something like:
# $ ~/Desktop/make-specimens.sh autohint
# where the 'make-specimens.sh' file lives in a folder called 'scripts' on your desktop
# note: the ~ is a shortcut to your user folder on your hardrive )
#
# To run the font through TTFAutohint, it must be installed!
# 
# If you don't want to autohint the fonts, type the following into your terminal instead:
# $ <path to script>/make-specimens.sh
# In practice, that looks something like:
# $ ~/Desktop/make-specimens.sh
# # # # # # # # # # # # # #

# Change line 35 to the path of the folder that has your html and css in it,
# do not include the trailing forward slash
# Alternately, just throw the 'specimens-1' folder on your desktop and leave the line 
# as it is.
specimenPath=~/Desktop/specimens-1

echo
echo "Making a the specimen folder and copying files..."
mkdir specimens
mkdir specimens/fonts
cp "$specimenPath"/style.css specimens/
echo

echo "Looping through the fonts..."
echo

# Loop through all files with a .ttf extension
for font in *.ttf
do
	echo "Working on $font..."
	
	# cut the extension off the font's filename
	fontName=${font%.*}
	
	# Copy the index.html but give it the font's name
	cp "$specimenPath"/index.html specimens/"$fontName".html
	
	# If the first argument in the command line is "autohint" then
	# autohint the fonts...
	if [ "$1" = "autohint" ]
	then
		echo "Autohinting..."
		# Run the fonts through TTFAutohint
		ttfautohint "$font" specimens/fonts/"$fontName"-ah.ttf
		# Rename the fonts, remove the '-ah' bit
		mv specimens/fonts/$fontName-ah.ttf specimens/fonts/"$font"
		
	# If not, don't autohint and just copy the fonts over
	else
		echo "Just copying, not autohinting..."
		cp "$font" specimens/fonts
	fi
	
	# Find/replace 'fileName' with the font's name in the html
	sed -i '' "s/fileName/$font/g" specimens/"$fontName".html
done

echo
echo "Done!"
echo

# # # # # # # # # # # # # #
# script written by & from: https://processtypefoundry.com
# # # # # # # # # # # # # #







